Command

Enum Command 

pub enum Command<N: Network> {
Show 14 variants Instruction(Instruction<N>), Await(Await<N>), Contains(Contains<N>), ContainsDynamic(ContainsDynamic<N>), Get(Get<N>), GetDynamic(GetDynamic<N>), GetOrUse(GetOrUse<N>), GetOrUseDynamic(GetOrUseDynamic<N>), RandChaCha(RandChaCha<N>), Remove(Remove<N>), Set(Set<N>), BranchEq(BranchEq<N>), BranchNeq(BranchNeq<N>), Position(Position<N>),
}

Variants



Instruction(Instruction<N>)

Evaluates the instruction.



Await(Await<N>)

Awaits the result of a future.



Contains(Contains<N>)

Returns true if the key operand is present in mapping, and stores the result into destination.



ContainsDynamic(ContainsDynamic<N>)

Resolves the program and mapping operands, returns true if the key operand is present in the mapping, and stores the result into destination.



Get(Get<N>)

Gets the value stored at the key operand in mapping and stores the result into destination.



GetDynamic(GetDynamic<N>)

Resolves the program and mapping operands, gets the value stored at the key operand in mapping, and stores the result into destination.



GetOrUse(GetOrUse<N>)

Gets the value stored at the key operand in mapping and stores the result into destination. If the key is not present, default is stored into destination.



GetOrUseDynamic(GetOrUseDynamic<N>)

Resolves the program and mapping operands, gets the value stored at the key operand in mapping, and stores the result into destination. If the key is not present, default is stored into destination.



RandChaCha(RandChaCha<N>)

Generates a random value using the rand.chacha command and stores the result into destination.



Remove(Remove<N>)

Removes the (key, value) entry from the mapping.



Set(Set<N>)

Sets the value stored at the key operand in the mapping to value.



BranchEq(BranchEq<N>)

Jumps to the position, if first equals second.



BranchNeq(BranchNeq<N>)

Jumps to the position, if first does not equal second.



Position(Position<N>)

Indicates a position to which the program can branch to.

Implementations

Source

impl<N: Network> Command<N>

pub fn is_async(&self) -> bool

Returns true if the command is an async instruction.

pub fn is_await(&self) -> bool

Returns true if the command is an await command.

pub fn is_call(&self) -> bool

Returns true if the command is a call instruction.

pub fn is_cast_to_record(&self) -> bool

Returns true if the command is a cast to record instruction.

pub fn is_write(&self) -> bool

Returns true if the command is a write operation.

pub fn branch_to(&self) -> Option<&Identifier<N>>

Returns the branch target, if the command is a branch command. Otherwise, returns None.

pub fn position(&self) -> Option<&Identifier<N>>

Returns the position name, if the command is a position command. Otherwise, returns None.

pub fn destinations(&self) -> Vec<Register<N>>

Returns the destination registers of the command.

pub fn operands(&self) -> &[Operand<N>]

Returns the operands of the command.

pub fn finalize( &self, stack: &impl StackTrait<N>, store: &impl FinalizeStoreTrait<N>, registers: &mut impl FinalizeRegistersState<N>, ) -> Result<Option<FinalizeOperation<N>>>

Finalizes the command.

pub fn contains_external_struct(&self) -> bool

Returns whether this commands refers to an external struct.

pub fn contains_string_type(&self) -> bool

Returns true if the command contains a string type.

pub fn contains_identifier_type(&self) -> Result<bool>

Returns true if the command contains an identifier type in its cast type.

pub fn exceeds_max_array_size(&self, max_array_size: u32) -> bool

Returns true if the command contains an array type with a size that exceeds the given maximum.