GetOrUseDynamic

Struct GetOrUseDynamic 

pub struct GetOrUseDynamic<N: Network> { /* private fields */ }
A dynamic get.or_use command that uses the provided default in case of failure, e.g. get.or_use.dynamic r0 r1 r2[r3] r4 into r5 as boolean;. Resolves the program and mapping operands, gets the value stored at the key operand in mapping, and stores the result into destination. If the key is not present, default is stored in destination.

Implementations

Source

impl<N: Network> GetOrUseDynamic<N>

pub const fn opcode() -> Opcode

Returns the opcode.

pub fn operands(&self) -> &[Operand<N>]

Returns the operands in the operation.

pub const fn program_name_operand(&self) -> &Operand<N>

Returns the operand containing the program name.

pub const fn program_network_operand(&self) -> &Operand<N>

Returns the operand containing the program network.

pub const fn mapping_name_operand(&self) -> &Operand<N>

Returns the operand containing the mapping name.

pub const fn key_operand(&self) -> &Operand<N>

Returns the operand containing the key.

pub const fn default_operand(&self) -> &Operand<N>

Returns the operand containing the default value.

pub const fn destination(&self) -> &Register<N>

Returns the destination register.

pub const fn destination_type(&self) -> &PlaintextType<N>

Returns the destination type.

Source

impl<N: Network> GetOrUseDynamic<N>

pub fn finalize( &self, stack: &impl StackTrait<N>, store: &impl FinalizeStoreTrait<N>, registers: &mut impl RegistersTrait<N>, ) -> Result<()>

Finalizes the command.