pub struct ClosureCore<N: Network> { /* private fields */ }Implementations
Sourceimpl<N: Network> ClosureCore<N>
impl<N: Network> ClosureCore<N>
Sourcepub fn new(name: Identifier<N>) -> Self
pub fn new(name: Identifier<N>) -> Self
Initializes a new closure with the given name.
Sourcepub const fn name(&self) -> &Identifier<N>
pub const fn name(&self) -> &Identifier<N>
Returns the name of the closure.
Sourcepub fn instructions(&self) -> &[Instruction<N>]
pub fn instructions(&self) -> &[Instruction<N>]
Returns the closure instructions.
Sourcepub fn output_types(&self) -> Vec<RegisterType<N>>
pub fn output_types(&self) -> Vec<RegisterType<N>>
Returns the closure output types.
Sourcepub fn contains_external_struct(&self) -> bool
pub fn contains_external_struct(&self) -> bool
Returns whether the closure refers to an external struct.
Sourcepub fn contains_string_type(&self) -> bool
pub fn contains_string_type(&self) -> bool
Returns true if the closure instructions contain a string type.
Note that input and output types don’t have to be checked if we are sure the broader function doesn’t contain a string type.
Sourcepub fn contains_identifier_type(&self) -> Result<bool>
pub fn contains_identifier_type(&self) -> Result<bool>
Returns true if the closure contains an identifier type in its inputs, outputs, or instructions.
Sourcepub fn exceeds_max_array_size(&self, max_array_size: u32) -> bool
pub fn exceeds_max_array_size(&self, max_array_size: u32) -> bool
Returns true if the closure contains an array type with a size that exceeds the given maximum.
Sourceimpl<N: Network> ClosureCore<N>
impl<N: Network> ClosureCore<N>
Sourcepub fn add_instruction(&mut self, instruction: Instruction<N>) -> Result<()>
pub fn add_instruction(&mut self, instruction: Instruction<N>) -> Result<()>
Adds the given instruction to the closure.
Errors
This method will halt if there are output statements already. This method will halt if the maximum number of instructions has been reached.