pub struct GetOrUseDynamic<N: Network> { /* private fields */ }Expand description
A dynamic get.or_use command that uses the provided default in case of failure, e.g. get.or_use.dynamic r0 r1 r2[r3] r4 into r5 as boolean;.
Resolves the program and mapping operands, gets the value stored at the key operand in mapping, and stores the result into destination.
If the key is not present, default is stored in destination.
Implementations
Sourceimpl<N: Network> GetOrUseDynamic<N>
impl<N: Network> GetOrUseDynamic<N>
Sourcepub const fn program_name_operand(&self) -> &Operand<N>
pub const fn program_name_operand(&self) -> &Operand<N>
Returns the operand containing the program name.
Sourcepub const fn program_network_operand(&self) -> &Operand<N>
pub const fn program_network_operand(&self) -> &Operand<N>
Returns the operand containing the program network.
Sourcepub const fn mapping_name_operand(&self) -> &Operand<N>
pub const fn mapping_name_operand(&self) -> &Operand<N>
Returns the operand containing the mapping name.
Sourcepub const fn key_operand(&self) -> &Operand<N>
pub const fn key_operand(&self) -> &Operand<N>
Returns the operand containing the key.
Sourcepub const fn default_operand(&self) -> &Operand<N>
pub const fn default_operand(&self) -> &Operand<N>
Returns the operand containing the default value.
Sourcepub const fn destination(&self) -> &Register<N>
pub const fn destination(&self) -> &Register<N>
Returns the destination register.
Sourcepub const fn destination_type(&self) -> &PlaintextType<N>
pub const fn destination_type(&self) -> &PlaintextType<N>
Returns the destination type.
Sourceimpl<N: Network> GetOrUseDynamic<N>
impl<N: Network> GetOrUseDynamic<N>
Sourcepub fn finalize(
&self,
stack: &impl StackTrait<N>,
store: &impl FinalizeStoreTrait<N>,
registers: &mut impl RegistersTrait<N>,
) -> Result<()>
pub fn finalize( &self, stack: &impl StackTrait<N>, store: &impl FinalizeStoreTrait<N>, registers: &mut impl RegistersTrait<N>, ) -> Result<()>
Finalizes the command.